Test Type Text Events
open | ../tests/html/test_form_events.html |
verifyValue | theTextbox |
verifyValue | eventlog |
type | theTextbox | first value
verifyValue | theTextbox | first value
verifyValue | eventlog | {focus(theTextbox)} {select(theTextbox)} {change(theTextbox)}
type | eventlog |
type | theTextbox | changed value
verifyValue | theTextbox | changed value
verifyValue | eventlog | {focus(theTextbox)} {select(theTextbox)} {change(theTextbox)}